@@ -184,10 +184,10 @@ class Client(object):
                     fix = ''
                 batfile.write(u"""
 @echo off
-echo Waiting for file handle to be closed ...
+echo Updating to latest version...
 ping 127.0.0.1 -n 5 -w 1000 > NUL
 move /Y "{}" "{}" > NUL
-echo Updating to latest version...
+echo restarting...
 start {} "{}" """.format(updated_app, current_app, fix, current_app))
             os.startfile(bat)
             sys.exit(0)
