@@ -333,11 +333,6 @@ class PackageHandler(object):
                         s['patch_md5'] = _get_package_hashes(i[1])
                         break
 
-            with open('manifest.txt', 'w') as m:
-                m.write(json.dumps(self.package_manifest, indent=2,
-                        sort_keys=True))
-                m.write('\nDone!!')
-
     def _get_platform(self, name):
         platform_name = re.compile('[macnixw0-9]{3,5}').findall(name)[0]
         log.debug('Platform name is: {}'.format(platform_name))
